@@ -3,6 +3,7 @@
 pub mod args;
 pub mod builtin;
 pub mod call;
+pub mod callable_function;
 pub mod func;
 pub mod hashing;
 pub mod native;
@@ -13,6 +14,7 @@ pub mod script;
 pub use args::FuncArgs;
 pub use builtin::{get_builtin_binary_op_fn, get_builtin_op_assignment_fn};
 pub use call::FnCallArgs;
+pub use callable_function::CallableFunction;
 #[cfg(not(feature = "no_function"))]
 pub use func::Func;
 pub use hashing::{
@@ -20,8 +22,8 @@ pub use hashing::{
     combine_hashes, get_hasher,
 };
 pub use native::{
-    shared_make_mut, shared_take, shared_take_or_clone, shared_try_take, shared_write_lock,
-    CallableFunction, FnAny, FnPlugin, IteratorFn, Locked, NativeCallContext, SendSync, Shared,
+    shared_make_mut, shared_take, shared_take_or_clone, shared_try_take, shared_write_lock, FnAny,
+    FnPlugin, IteratorFn, Locked, NativeCallContext, SendSync, Shared,
 };
 pub use plugin::PluginFunction;
 pub use register::RegisterNativeFunction;
