@@ -15,6 +15,7 @@ use crate::{
 use std::prelude::v1::*;
 use std::{
     any::TypeId,
+    cmp::Ordering,
     collections::{BTreeMap, BTreeSet},
     fmt,
     iter::{empty, once},
@@ -31,11 +32,9 @@ pub enum FnNamespace {
     Internal,
 }
 
-/// Data structure containing a single registered function.
-#[derive(Debug, Clone)]
-pub struct FuncInfo {
-    /// Function instance.
-    pub func: Shared<CallableFunction>,
+/// A type containing all metadata for a registered function.
+#[derive(Debug, Clone, Eq, PartialEq, Hash)]
+pub struct FnMetadata {
     /// Function namespace.
     pub namespace: FnNamespace,
     /// Function access mode.
@@ -44,61 +43,158 @@ pub struct FuncInfo {
     pub name: Identifier,
     /// Number of parameters.
     pub params: usize,
-    /// Parameter types (if applicable).
-    pub param_types: StaticVec<TypeId>,
     /// Parameter names and types (if available).
     #[cfg(feature = "metadata")]
-    pub param_names_and_types: StaticVec<Identifier>,
+    pub params_info: StaticVec<Identifier>,
     /// Return type name.
     #[cfg(feature = "metadata")]
-    pub return_type_name: Identifier,
+    pub return_type: Identifier,
     /// Comments.
     #[cfg(feature = "metadata")]
     pub comments: Option<Box<[Box<str>]>>,
 }
 
+impl PartialOrd for FnMetadata {
+    fn partial_cmp(&self, other: &Self) -> Option<Ordering> {
+        Some(self.cmp(other))
+    }
+}
+
+impl Ord for FnMetadata {
+    fn cmp(&self, other: &Self) -> Ordering {
+        match self.name.cmp(&other.name) {
+            #[cfg(feature = "metadata")]
+            Ordering::Equal => match self.params.cmp(&other.params) {
+                Ordering::Equal => self.params_info.cmp(&other.params_info),
+                cmp => cmp,
+            },
+            #[cfg(not(feature = "metadata"))]
+            Ordering::Equal => self.params.cmp(&other.params),
+            cmp => cmp,
+        }
+    }
+}
+
+/// A type containing a single registered function.
+#[derive(Debug, Clone)]
+pub struct FuncInfo {
+    /// Function instance.
+    pub func: Shared<CallableFunction>,
+    /// Parameter types (if applicable).
+    pub param_types: StaticVec<TypeId>,
+    /// Function metadata.
+    pub metadata: FnMetadata,
+}
+
 impl FuncInfo {
+    /// Format a return type to be display-friendly.
+    ///
+    /// `()` is cleared.  
+    /// [`RhaiResult`][crate::RhaiResult] and [`RhaiResultOf<T>`] are expanded.
+    #[cfg(feature = "metadata")]
+    pub fn format_type(typ: &str, is_return_type: bool) -> std::borrow::Cow<str> {
+        const RHAI_RESULT_TYPE: &str = "RhaiResult";
+        const RHAI_RESULT_TYPE_EXPAND: &str = "Result<Dynamic, Box<EvalAltResult>>";
+        const RHAI_RESULT_OF_TYPE: &str = "RhaiResultOf<";
+        const RHAI_RESULT_OF_TYPE_EXPAND: &str = "Result<{}, Box<EvalAltResult>>";
+        const RHAI_RANGE: &str = "ExclusiveRange";
+        const RHAI_RANGE_TYPE: &str = "Range<";
+        const RHAI_RANGE_EXPAND: &str = "Range<{}>";
+        const RHAI_INCLUSIVE_RANGE: &str = "InclusiveRange";
+        const RHAI_INCLUSIVE_RANGE_TYPE: &str = "RangeInclusive<";
+        const RHAI_INCLUSIVE_RANGE_EXPAND: &str = "RangeInclusive<{}>";
+
+        let typ = typ.trim();
+
+        if typ.starts_with("rhai::") {
+            return Self::format_type(&typ[6..], is_return_type);
+        } else if typ.starts_with("&mut ") {
+            let x = &typ[5..];
+            let r = Self::format_type(x, false);
+            return if r == x {
+                typ.into()
+            } else {
+                format!("&mut {}", r).into()
+            };
+        }
+
+        match typ {
+            "" | "()" if is_return_type => "".into(),
+            "INT" => std::any::type_name::<crate::INT>().into(),
+            #[cfg(not(feature = "no_float"))]
+            "FLOAT" => std::any::type_name::<crate::FLOAT>().into(),
+            RHAI_RANGE => RHAI_RANGE_EXPAND
+                .replace("{}", std::any::type_name::<crate::INT>())
+                .into(),
+            RHAI_INCLUSIVE_RANGE => RHAI_INCLUSIVE_RANGE_EXPAND
+                .replace("{}", std::any::type_name::<crate::INT>())
+                .into(),
+            RHAI_RESULT_TYPE => RHAI_RESULT_TYPE_EXPAND.into(),
+            ty if ty.starts_with(RHAI_RANGE_TYPE) && ty.ends_with('>') => {
+                let inner = &ty[RHAI_RANGE_TYPE.len()..ty.len() - 1];
+                RHAI_RANGE_EXPAND
+                    .replace("{}", Self::format_type(inner, false).trim())
+                    .into()
+            }
+            ty if ty.starts_with(RHAI_INCLUSIVE_RANGE_TYPE) && ty.ends_with('>') => {
+                let inner = &ty[RHAI_INCLUSIVE_RANGE_TYPE.len()..ty.len() - 1];
+                RHAI_INCLUSIVE_RANGE_EXPAND
+                    .replace("{}", Self::format_type(inner, false).trim())
+                    .into()
+            }
+            ty if ty.starts_with(RHAI_RESULT_OF_TYPE) && ty.ends_with('>') => {
+                let inner = &ty[RHAI_RESULT_OF_TYPE.len()..ty.len() - 1];
+                RHAI_RESULT_OF_TYPE_EXPAND
+                    .replace("{}", Self::format_type(inner, false).trim())
+                    .into()
+            }
+            ty => ty.into(),
+        }
+    }
     /// Generate a signature of the function.
     /// Exported under the `metadata` feature only.
     #[cfg(feature = "metadata")]
     #[must_use]
     pub fn gen_signature(&self) -> String {
-        let mut sig = format!("{}(", self.name);
+        let mut sig = format!("{}(", self.metadata.name);
 
-        if !self.param_names_and_types.is_empty() {
+        let return_type = Self::format_type(&self.metadata.return_type, true);
+
+        if !self.metadata.params_info.is_empty() {
             let params: StaticVec<_> = self
-                .param_names_and_types
+                .metadata
+                .params_info
                 .iter()
-                .map(|s| s.as_str())
+                .map(|s| {
+                    let mut seg = s.splitn(2, ':');
+                    let name = match seg.next().unwrap().trim() {
+                        "" => "_",
+                        s => s,
+                    };
+                    let result: std::borrow::Cow<str> = match seg.next() {
+                        Some(typ) => {
+                            format!("{}: {}", name, FuncInfo::format_type(typ, false)).into()
+                        }
+                        None => name.into(),
+                    };
+                    result
+                })
                 .collect();
             sig.push_str(&params.join(", "));
-            sig.push_str(")");
-
-            match self.return_type_name.as_str() {
-                "" | "()" => (),
-                ty => {
-                    sig.push_str(" -> ");
-                    sig.push_str(ty);
-                }
-            }
+            sig.push(')');
         } else {
-            for x in 0..self.params {
+            for x in 0..self.metadata.params {
                 sig.push('_');
-                if x < self.params - 1 {
+                if x < self.metadata.params - 1 {
                     sig.push_str(", ");
                 }
             }
+            sig.push(')');
+        }
 
-            if self.func.is_script() {
-                sig.push(')');
-            } else {
-                sig.push_str(")");
-
-                match self.return_type_name.as_str() {
-                    "()" => (),
-                    _ => sig.push_str(" -> ?"),
-                }
-            }
+        if !self.func.is_script() && !return_type.is_empty() {
+            sig.push_str(" -> ");
+            sig.push_str(&return_type);
         }
 
         sig
@@ -372,7 +468,7 @@ impl Module {
     #[inline]
     pub fn gen_fn_signatures(&self) -> impl Iterator<Item = String> + '_ {
         self.iter_fn()
-            .filter(|&f| match f.access {
+            .filter(|&f| match f.metadata.access {
                 FnAccess::Public => true,
                 FnAccess::Private => false,
             })
@@ -478,22 +574,24 @@ impl Module {
         let num_params = fn_def.params.len();
         let hash_script = crate::calc_fn_hash(&fn_def.name, num_params);
         #[cfg(feature = "metadata")]
-        let param_names_and_types = fn_def.params.iter().cloned().collect();
+        let params_info = fn_def.params.iter().cloned().collect();
         self.functions.insert(
             hash_script,
             FuncInfo {
-                name: fn_def.name.clone(),
-                namespace: FnNamespace::Internal,
-                access: fn_def.access,
-                params: num_params,
-                param_types: StaticVec::new_const(),
-                #[cfg(feature = "metadata")]
-                param_names_and_types,
-                #[cfg(feature = "metadata")]
-                return_type_name: "Dynamic".into(),
-                #[cfg(feature = "metadata")]
-                comments: None,
+                metadata: FnMetadata {
+                    name: fn_def.name.clone(),
+                    namespace: FnNamespace::Internal,
+                    access: fn_def.access,
+                    params: num_params,
+                    #[cfg(feature = "metadata")]
+                    params_info,
+                    #[cfg(feature = "metadata")]
+                    return_type: "".into(),
+                    #[cfg(feature = "metadata")]
+                    comments: None,
+                },
                 func: Into::<CallableFunction>::into(fn_def).into(),
+                param_types: StaticVec::new_const(),
             }
             .into(),
         );
@@ -518,7 +616,7 @@ impl Module {
             let name = name.as_ref();
 
             self.iter_fn()
-                .find(|f| f.params == num_params && f.name == name)
+                .find(|f| f.metadata.params == num_params && f.metadata.name == name)
                 .and_then(|f| f.func.get_script_fn_def())
         }
     }
@@ -648,14 +746,14 @@ impl Module {
             .collect();
 
         if let Some(f) = self.functions.get_mut(&hash_fn) {
-            let (param_names, return_type_name) = if param_names.len() > f.params {
+            let (param_names, return_type_name) = if param_names.len() > f.metadata.params {
                 let return_type = param_names.pop().unwrap();
                 (param_names, return_type)
             } else {
-                (param_names, Default::default())
+                (param_names, crate::SmartString::new_const())
             };
-            f.param_names_and_types = param_names;
-            f.return_type_name = return_type_name;
+            f.metadata.params_info = param_names;
+            f.metadata.return_type = return_type_name;
         }
 
         self
@@ -698,7 +796,7 @@ impl Module {
 
         if !comments.is_empty() {
             let f = self.functions.get_mut(&hash_fn).unwrap();
-            f.comments = Some(comments.iter().map(|s| s.as_ref().into()).collect());
+            f.metadata.comments = Some(comments.iter().map(|s| s.as_ref().into()).collect());
         }
 
         self
@@ -710,7 +808,7 @@ impl Module {
     #[inline]
     pub fn update_fn_namespace(&mut self, hash_fn: u64, namespace: FnNamespace) -> &mut Self {
         if let Some(f) = self.functions.get_mut(&hash_fn) {
-            f.namespace = namespace;
+            f.metadata.namespace = namespace;
             self.indexed = false;
             self.contains_indexed_global_functions = false;
         }
@@ -784,7 +882,7 @@ impl Module {
             let return_type = if names.len() > arg_types.as_ref().len() {
                 names.pop().unwrap()
             } else {
-                Default::default()
+                crate::SmartString::new_const()
             };
             names.shrink_to_fit();
             (names, return_type)
@@ -795,18 +893,20 @@ impl Module {
         self.functions.insert(
             hash_fn,
             FuncInfo {
-                name: name.as_ref().into(),
-                namespace,
-                access,
-                params: param_types.len(),
-                param_types,
-                #[cfg(feature = "metadata")]
-                param_names_and_types: param_names,
-                #[cfg(feature = "metadata")]
-                return_type_name,
-                #[cfg(feature = "metadata")]
-                comments: None,
+                metadata: FnMetadata {
+                    name: name.as_ref().into(),
+                    namespace,
+                    access,
+                    params: param_types.len(),
+                    #[cfg(feature = "metadata")]
+                    params_info: param_names,
+                    #[cfg(feature = "metadata")]
+                    return_type: return_type_name,
+                    #[cfg(feature = "metadata")]
+                    comments: None,
+                },
                 func: func.into(),
+                param_types,
             }
             .into(),
         );
@@ -861,7 +961,7 @@ impl Module {
 
         if !comments.is_empty() {
             let f = self.functions.get_mut(&hash).unwrap();
-            f.comments = Some(comments.iter().map(|s| s.as_ref().into()).collect());
+            f.metadata.comments = Some(comments.iter().map(|s| s.as_ref().into()).collect());
         }
 
         hash
@@ -1347,14 +1447,14 @@ impl Module {
     /// Merge another [`Module`] into this [`Module`].
     #[inline(always)]
     pub fn merge(&mut self, other: &Self) -> &mut Self {
-        self.merge_filtered(other, &|_, _, _, _, _| true)
+        self.merge_filtered(other, |_, _, _, _, _| true)
     }
 
     /// Merge another [`Module`] into this [`Module`] based on a filter predicate.
     pub(crate) fn merge_filtered(
         &mut self,
         other: &Self,
-        _filter: &impl Fn(FnNamespace, FnAccess, bool, &str, usize) -> bool,
+        _filter: impl Fn(FnNamespace, FnAccess, bool, &str, usize) -> bool + Copy,
     ) -> &mut Self {
         #[cfg(not(feature = "no_function"))]
         other.modules.iter().for_each(|(k, v)| {
@@ -1374,11 +1474,11 @@ impl Module {
                 .iter()
                 .filter(|&(_, f)| {
                     _filter(
-                        f.namespace,
-                        f.access,
+                        f.metadata.namespace,
+                        f.metadata.access,
                         f.func.is_script(),
-                        f.name.as_str(),
-                        f.params,
+                        f.metadata.name.as_str(),
+                        f.metadata.params,
                     )
                 })
                 .map(|(&k, v)| (k, v.clone())),
@@ -1404,7 +1504,12 @@ impl Module {
             .into_iter()
             .filter(|(_, f)| {
                 if f.func.is_script() {
-                    filter(f.namespace, f.access, f.name.as_str(), f.params)
+                    filter(
+                        f.metadata.namespace,
+                        f.metadata.access,
+                        f.metadata.name.as_str(),
+                        f.metadata.params,
+                    )
                 } else {
                     false
                 }
@@ -1472,10 +1577,10 @@ impl Module {
     > + '_ {
         self.iter_fn().filter(|&f| f.func.is_script()).map(|f| {
             (
-                f.namespace,
-                f.access,
-                f.name.as_str(),
-                f.params,
+                f.metadata.namespace,
+                f.metadata.access,
+                f.metadata.name.as_str(),
+                f.metadata.params,
                 f.func.get_script_fn_def().expect("script-defined function"),
             )
         })
@@ -1494,9 +1599,14 @@ impl Module {
     pub fn iter_script_fn_info(
         &self,
     ) -> impl Iterator<Item = (FnNamespace, FnAccess, &str, usize)> {
-        self.iter_fn()
-            .filter(|&f| f.func.is_script())
-            .map(|f| (f.namespace, f.access, f.name.as_str(), f.params))
+        self.iter_fn().filter(|&f| f.func.is_script()).map(|f| {
+            (
+                f.metadata.namespace,
+                f.metadata.access,
+                f.metadata.name.as_str(),
+                f.metadata.params,
+            )
+        })
     }
 
     /// _(internals)_ Get an iterator over all script-defined functions in the [`Module`].
@@ -1555,7 +1665,7 @@ impl Module {
     ) -> RhaiResultOf<Self> {
         let mut scope = scope;
         let mut global = crate::eval::GlobalRuntimeState::new();
-        let orig_mods_len = global.num_imported_modules();
+        let orig_mods_len = global.num_imports();
 
         // Run the script
         engine.eval_ast_with_scope_raw(&mut scope, &mut global, &ast, 0)?;
@@ -1607,7 +1717,7 @@ impl Module {
         if ast.has_functions() {
             ast.shared_lib()
                 .iter_fn()
-                .filter(|&f| match f.access {
+                .filter(|&f| match f.metadata.access {
                     FnAccess::Public => true,
                     FnAccess::Private => false,
                 })
@@ -1682,7 +1792,7 @@ impl Module {
 
             // Index all Rust functions
             module.functions.iter().for_each(|(&hash, f)| {
-                match f.namespace {
+                match f.metadata.namespace {
                     FnNamespace::Global => {
                         // Flatten all functions with global namespace
                         functions.insert(hash, f.func.clone());
@@ -1690,20 +1800,23 @@ impl Module {
                     }
                     FnNamespace::Internal => (),
                 }
-                match f.access {
+                match f.metadata.access {
                     FnAccess::Public => (),
                     FnAccess::Private => return, // Do not index private functions
                 }
 
                 if !f.func.is_script() {
-                    let hash_qualified_fn =
-                        calc_native_fn_hash(path.iter().cloned(), f.name.as_str(), &f.param_types);
+                    let hash_qualified_fn = calc_native_fn_hash(
+                        path.iter().cloned(),
+                        f.metadata.name.as_str(),
+                        &f.param_types,
+                    );
                     functions.insert(hash_qualified_fn, f.func.clone());
                 } else if cfg!(not(feature = "no_function")) {
                     let hash_qualified_script = crate::calc_qualified_fn_hash(
                         path.iter().cloned(),
-                        f.name.as_str(),
-                        f.params,
+                        f.metadata.name.as_str(),
+                        f.metadata.params,
                     );
                     functions.insert(hash_qualified_script, f.func.clone());
                 }
