@@ -1,6 +1,5 @@
 #![cfg(not(feature = "no_std"))]
-#![cfg(not(target_arch = "wasm32"))]
-#![cfg(not(target_arch = "wasm64"))]
+#![cfg(not(target_family = "wasm"))]
 
 use crate::func::native::shared_write_lock;
 use crate::{
