@@ -96,7 +96,7 @@ impl<'a> OptimizerState<'a> {
     pub fn restore_var(&mut self, len: usize) {
         self.variables.truncate(len)
     }
-    /// Add a new constant to the list.
+    /// Add a new variable to the list.
     #[inline(always)]
     pub fn push_var(
         &mut self,
@@ -423,7 +423,7 @@ fn optimize_stmt(stmt: &mut Stmt, state: &mut OptimizerState, preserve_result: b
             match x.2 {
                 Expr::FnCall(ref mut x2, _) => {
                     state.set_dirty();
-                    x.1 = Some(OpAssignment::new(&x2.name));
+                    x.1 = Some(OpAssignment::new_from_base(&x2.name));
 
                     let value = mem::take(&mut x2.args[1]);
 
