@@ -47,8 +47,8 @@ def_package! {
         {
             reg_functions!(lib += numbers; i8, u8, i16, u16, i32, u32, u64);
 
-            #[cfg(not(target_arch = "wasm32"))]
-            #[cfg(not(target_arch = "wasm64"))]
+            #[cfg(not(target_family = "wasm"))]
+
             reg_functions!(lib += num_128; i128, u128);
         }
 
@@ -62,6 +62,8 @@ def_package! {
             reg_functions!(lib += float; f64);
             combine_with_exported_module!(lib, "f64", f64_functions);
         }
+
+        combine_with_exported_module!(lib, "logic", logic_functions);
     }
 }
 
@@ -71,8 +73,8 @@ gen_cmp_functions!(numbers => i8, u8, i16, u16, i32, u32, u64);
 
 #[cfg(not(feature = "only_i32"))]
 #[cfg(not(feature = "only_i64"))]
-#[cfg(not(target_arch = "wasm32"))]
-#[cfg(not(target_arch = "wasm64"))]
+#[cfg(not(target_family = "wasm"))]
+
 gen_cmp_functions!(num_128 => i128, u128);
 
 #[cfg(not(feature = "no_float"))]
@@ -83,6 +85,14 @@ gen_cmp_functions!(float => f32);
 #[cfg(feature = "f32_float")]
 gen_cmp_functions!(float => f64);
 
+#[export_module]
+mod logic_functions {
+    #[rhai_fn(name = "!")]
+    pub fn not(x: bool) -> bool {
+        !x
+    }
+}
+
 #[cfg(not(feature = "no_float"))]
 #[export_module]
 mod f32_functions {
