@@ -15,12 +15,11 @@ use std::{
 };
 
 #[cfg(not(feature = "no_std"))]
-#[cfg(not(target_arch = "wasm32"))]
-#[cfg(not(target_arch = "wasm64"))]
+#[cfg(not(target_family = "wasm"))]
 use std::time::Instant;
 
 #[cfg(not(feature = "no_std"))]
-#[cfg(any(target_arch = "wasm32", target_arch = "wasm64"))]
+#[cfg(target_family = "wasm")]
 use instant::Instant;
 
 /// The message: data type was checked
@@ -525,8 +524,7 @@ impl Hash for Dynamic {
                         value_any.downcast_ref::<i64>().expect(CHECKED).hash(state);
                     }
 
-                    #[cfg(not(target_arch = "wasm32"))]
-                    #[cfg(not(target_arch = "wasm64"))]
+                    #[cfg(not(target_family = "wasm"))]
                     if type_id == TypeId::of::<u128>() {
                         TypeId::of::<u128>().hash(state);
                         value_any.downcast_ref::<u128>().expect(CHECKED).hash(state);
@@ -548,44 +546,66 @@ impl Hash for Dynamic {
 /// Map the name of a standard type into a friendly form.
 #[inline]
 #[must_use]
-pub(crate) fn map_std_type_name(name: &str) -> &str {
+pub(crate) fn map_std_type_name(name: &str, shorthands: bool) -> &str {
+    let name = name.trim();
+
+    if name.starts_with("rhai::") {
+        return map_std_type_name(&name[6..], shorthands);
+    }
+
     if name == type_name::<String>() {
-        return "string";
+        return if shorthands { "string" } else { "String" };
     }
     if name == type_name::<ImmutableString>() {
-        return "string";
+        return if shorthands {
+            "string"
+        } else {
+            "ImmutableString"
+        };
     }
     if name == type_name::<&str>() {
-        return "string";
-    }
-    if name == type_name::<FnPtr>() {
-        return "Fn";
+        return if shorthands { "string" } else { "&str" };
     }
     #[cfg(feature = "decimal")]
     if name == type_name::<rust_decimal::Decimal>() {
-        return "decimal";
+        return if shorthands { "decimal" } else { "Decimal" };
+    }
+    if name == type_name::<FnPtr>() {
+        return if shorthands { "Fn" } else { "FnPtr" };
     }
     #[cfg(not(feature = "no_index"))]
     if name == type_name::<crate::Array>() {
-        return "array";
+        return if shorthands { "array" } else { "Array" };
     }
     #[cfg(not(feature = "no_index"))]
     if name == type_name::<crate::Blob>() {
-        return "blob";
+        return if shorthands { "blob" } else { "Blob" };
     }
     #[cfg(not(feature = "no_object"))]
     if name == type_name::<crate::Map>() {
-        return "map";
+        return if shorthands { "map" } else { "Map" };
     }
     #[cfg(not(feature = "no_std"))]
     if name == type_name::<Instant>() {
-        return "timestamp";
+        return if shorthands { "timestamp" } else { "Instant" };
     }
-    if name == type_name::<ExclusiveRange>() {
-        return "range";
+    if name == type_name::<ExclusiveRange>() || name == "ExclusiveRange" {
+        return if shorthands {
+            "range"
+        } else if cfg!(feature = "only_i32") {
+            "Range<i32>"
+        } else {
+            "Range<i64>"
+        };
     }
-    if name == type_name::<InclusiveRange>() {
-        return "range=";
+    if name == type_name::<InclusiveRange>() || name == "InclusiveRange" {
+        return if shorthands {
+            "range="
+        } else if cfg!(feature = "only_i32") {
+            "RangeInclusive<i32>"
+        } else {
+            "RangeInclusive<i64>"
+        };
     }
 
     name
@@ -650,8 +670,7 @@ impl fmt::Display for Dynamic {
 
                 #[cfg(not(feature = "only_i32"))]
                 #[cfg(not(feature = "only_i64"))]
-                #[cfg(not(target_arch = "wasm32"))]
-                #[cfg(not(target_arch = "wasm64"))]
+                #[cfg(not(target_family = "wasm"))]
                 if _type_id == TypeId::of::<u128>() {
                     return fmt::Display::fmt(_value_any.downcast_ref::<u128>().expect(CHECKED), f);
                 } else if _type_id == TypeId::of::<i128>() {
@@ -756,8 +775,7 @@ impl fmt::Debug for Dynamic {
 
                 #[cfg(not(feature = "only_i32"))]
                 #[cfg(not(feature = "only_i64"))]
-                #[cfg(not(target_arch = "wasm32"))]
-                #[cfg(not(target_arch = "wasm64"))]
+                #[cfg(not(target_family = "wasm"))]
                 if _type_id == TypeId::of::<u128>() {
                     return fmt::Debug::fmt(_value_any.downcast_ref::<u128>().expect(CHECKED), f);
                 } else if _type_id == TypeId::of::<i128>() {
